<?php 

require_once "conexionLocal.php";

function getVelocidad(){
	do{
		$archivoGps = fopen("/var/www/html/RegislogWeb/variables/gps.txt", "r") or die("No se puede abrir el archivo!");
		$fileGps = fgets($archivoGps);
		fclose($archivoGps);
		$gps = explode(",", $fileGps);
	}while(count($gps) <= 6);
	return printf("datosGps=".$gps[4]."+".$gps[0]."+".$gps[1]."+".$gps[5]."+".$gps[6]);

}

function datosMensajes(){

	$archivoMensage = fopen("/var/www/html/RegislogWeb/variables/mensaje.txt", "r") or die("No se puede abrir el archivo!");
	while (!feof($archivoMensage) ) {
		$line = fgets($archivoMensage);
		$Mensage[] = preg_replace('/[^A-Za-z0-9\-;:\/\s]/', '', $line);
	}
	fclose($archivoMensage);
	print json_encode($Mensage);
	
}

function datosRuta(){
	try{
		$midb = conexionLocalSQLite3();
		$midb->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
		$results = $midb->prepare('SELECT * FROM tablaRuta'); 
		$results->setFetchMode(PDO::FETCH_ASSOC);
		$results->execute();
		$file = 0;
		if($results){
			while($fila = $results->fetch()){
				$matriz[$file][0] = $fila['codigo'];
				$matriz[$file][1] = $fila['latitud'];
				$matriz[$file][2] = $fila['longitud'];
				$matriz[$file][3] = $fila['radio'];
				$matriz[$file][4] = $fila['tiempoBase'];
				$matriz[$file][5] = $fila['direccion'];
				$matriz[$file][6] = $fila['holgura'];
				$matriz[$file][7] = $fila['ruta'];
				$file++;
			}
		}
		//Cierra la conexión con la base de datos
		$results = null;
		$midb = null;
		//echo json_encode($matriz);
	    print json_encode($matriz);
	}catch(PDOException $e) {
    	echo "Lo siento hay un error en BD..  ". $e->getMessage() ;// Remove or modify after testing 
    	file_put_contents('PDOErrors.txt',date('[Y-m-d H:i:s]').", myfile.php, ". $e->getMessage()."\r\n", FILE_APPEND);  
 	}
	//return printf("Mostrando ruta");
}

function ConfigDisplayContador(){
	try{
		$midb = conexionLocalSQLite3();
		$midb->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
		$results = $midb->prepare('SELECT * FROM tablaConfiguracion'); 
		$results->setFetchMode(PDO::FETCH_ASSOC);
		$results->execute();
		if($results){
			while($fila = $results->fetch()){
				$valor = $fila['display'];
			}
		}
		//Cierra la conexión con la base de datos
		$results = null;
		$midb = null;
	    printf($valor);
	}catch(PDOException $e) {
    	echo "Lo siento hay un error en BD..  ". $e->getMessage() ;// Remove or modify after testing 
    	file_put_contents('PDOErrors.txt',date('[Y-m-d H:i:s]').", modelo_c.php, ConfigDisplayContador". $e->getMessage()."\r\n", FILE_APPEND);  
 	}
	//return printf("Mostrando ruta");
}

function solicitudContadores(){
	try{
	$midb = conexionLocalSQLite3();
	$midb->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
	$results = $midb->prepare('SELECT * FROM REGISTROS_CONTEO'); 
	$results->setFetchMode(PDO::FETCH_ASSOC);
	$results->execute();
	if($results){
		while($fila = $results->fetch()){
			$numeracion = $fila['NUMERACION'];
			$total_dia = $fila['TOTAL_DIA'];
			$entradas = $fila['ENTRADAS'];
			$salidas = $fila['SALIDAS'];	
		}

	}
	//Cierra la conexión con la base de datos
	$results = null;
	$midb = null;
	return printf($numeracion.','.$total_dia.','.$entradas.','.$salidas);
	}catch(PDOException $e) {
    	echo "Lo siento hay un error en BD..  ". $e->getMessage() ;// Remove or modify after testing 
    	file_put_contents('PDOErrors.txt',date('[Y-m-d H:i:s]').", vistas.php, solicitudContadores ". $e->getMessage()."\r\n", FILE_APPEND);  
 	}
}


function datosTarjeta(){
	do{
		$archivoCard = fopen("/var/www/html/RegislogWeb/variables/datosRfid.txt", "r") or die("No se puede abrir el archivo!");
		$fileCard = fgets($archivoCard);
		fclose($archivoCard);
		$card = explode(",", $fileCard);
	}while(count($card) < 3);

	print json_encode($card);
}

function mensajeLeido(){
	file_put_contents("/var/www/html/RegislogWeb/variables/mensaje.txt", "");
	print json_encode("OK");
}

 ?>