<?php 
//require "vistas_c.php";
require "modelo_c.php";

/*
Aplicación CRUD  CreateReadUpdateDelete
PHP tiene 2 métodos de envío de datos: POST y GET

Create  Afecta BD    POST Modelo
Read    No afecta BD GET  Vista
Update  Afecta BD    POST Modelo
Delete  Afecta BD    POST Modelo 
*/

$transaccion = $_POST["transaccion"];





function ejecutarTransaccion($transaccion){
	if ($transaccion=="getVelocidad") { 
		getVelocidad(); // Obtiene la velocidad en base de datos
	}
	
	if($transaccion=="datosRuta"){
		datosRuta();
	}

	if($transaccion=="datosTarjeta"){
		datosTarjeta();
	}

	if($transaccion=="datosMensajes"){
		datosMensajes();
	}
	
	if($transaccion=="mensajeLeido"){
		mensajeLeido();
	}
	if($transaccion=="ConfigDisplayContador"){
		ConfigDisplayContador();
	}
	if($transaccion=="solicitudContadores"){
		solicitudContadores();
	}
}
ejecutarTransaccion($transaccion);
 ?>